import styled from 'styled-components'
import Nav from '../Nav/Nav'
import Link from 'next/link'
import * as React from 'react'

const StyledLink = styled('a')({
  display: 'block',
  textDecoration: 'none',
  marginBottom: '2rem',
})

const Container = styled('span')({
  display: 'flex',
  alignItems: 'center',
  padding: '0 1rem',
  height: '2rem',
  margin: '0 0 0 auto',
  boxSizing: 'border-box',
  '@media (min-width: 720px)': {
    maxWidth: 360,
  },
})

const Base = styled('aside')({
  position: 'fixed',
  top: 0,
  left: '-100%',
  width: '100%',
  height: '100%',
  backgroundColor: 'var(--color-bg)',
  zIndex: 4,
  '@media (min-width: 720px)': {
    left: 0,
    width: `${100 / 3}%`,
    maxWidth: 'none',
    height: '100%',
    '+ *': {
      paddingLeft: `${100 / 3}%`,
      boxSizing: 'border-box',
    },
  },
})

const NavWrapper = styled('nav')({
  '--size-link': '3rem',
})

const Sidebar = ({
  data,
  brand: Brand,
}) => {
  const [dark, setDark] = React.useState(false)

  const toggleDarkMode = (b: boolean) => () => {
    setDark(b)
  }

  React.useEffect(() => {
    const stylesheets = Array.from(window.document.querySelectorAll('link[title]'))

    stylesheets.forEach(s => {
      if (s.getAttribute('rel').includes('alternate')) {
        s.setAttribute('rel', 'stylesheet')
        s.removeAttribute('disabled')
      } else {
        s.setAttribute('rel', 'alternate stylesheet')
        s.setAttribute('disabled', 'disabled')
      }
    })
  }, [dark])

  return (
    <Base>
      <Container>
        <input
          type="checkbox"
          defaultChecked={dark}
          onChange={toggleDarkMode(!dark)}
        />
      </Container>
      <NavWrapper>
        <Link
          href="/"
          passHref
        >
          <StyledLink>
            <Container>
              <Brand />
            </Container>
          </StyledLink>
        </Link>
        <Nav
          data={data.nav}
        />
      </NavWrapper>
    </Base>
  )
}

export default Sidebar
